@@ -2,8 +2,8 @@ update_vars <- function(input, possibilities){
   setdiff(possibilities, union(union(union(union(union(union(input$selectSubject,
                                                              input$selectStim),
                                                        input$selectResponse),
-                                                 input$selectArm),
-                                           input$selectArm2),
-                                     input$selectTime),
-                               input$selectTime2))
+                                                 input$selectArmInter),
+                                           input$selectArmIntra),
+                                     input$selectTimeIntra),
+                               input$selectTimeInter))
 }
